@@ -1,5 +1,5 @@
 cd `dirname $0`
 mkdir -p ../flatboat-build-linux
 cd ../flatboat-build-linux
-qmake ../flatboat/flatboat.pro
+qmake CONFIG+=unix-local-debug ../flatboat/flatboat.pro
 make
