@@ -71,6 +71,25 @@ static QString page2string(fz_text_page *page){
 	return str;
 }
 
+static QString adjustPageString(QString str, int minLineLength){
+	QStringList lines = str.split("\n");
+	if(minLineLength == -1){//auto
+		for(int i=0;i<lines.length();i++)
+			minLineLength = std::max(lines[i].length(),minLineLength);
+		minLineLength /= 2;
+	}
+	QString buf;
+	QString res;
+	for(int i=0;i<lines.length();i++){
+		buf += lines[i];
+		if(buf.length() >= minLineLength || i==lines.length()-1 || lines[i+1].length() >= minLineLength){
+			res += buf +"\n";
+			buf = "";
+		}
+	}
+	return res;
+}
+
 static QString block2string(fz_text_block *block, bool addNewLines){
 	fz_text_line *line;
 	fz_text_span *span;
@@ -701,7 +720,7 @@ bool QPdfImage::gotoPage(int pagenum,bool render){
 	regions.clear();
 	regions += textAreas(text_page,zoom_prv);
 	if(regions.length() > 0){
-		if(curRegionIdx == -1)
+		if(curRegionIdx == -1 || curRegionIdx >= regions.length())
 			curRegionIdx = 0;
 	} else
 		curRegionIdx = -1;
@@ -758,22 +777,25 @@ bool QPdfImage::gotoPage(int pagenum,bool render){
 
 void QPdfImage::paint(QPainter *painter, const QStyleOptionGraphicsItem*, QWidget*) {
 	if(textMode_prv){
+		painter->setPen(Qt::black);
+		painter->setBrush(Qt::black);
 		if(textDocument.isEmpty())
 			textDocument += document2stringList();
-		QLabel* ql = new QLabel(textDocument[pagenum_prv-1]);
+		QLabel* ql = new QLabel(adjustPageString(textDocument[pagenum_prv-1],-1/*auto*/));
 		QFont fnt = ql->font();
 		fnt.setPointSize(textModeFontSize_prv);
 		ql->setFont(fnt);
 		setWidth(parentItem()->width());
 		setHeight(ql->heightForWidth(width()));
 		ql->resize(width(),height());
-		ql->setMargin(10);
+		ql->setMargin(20);
 		//painter->translate(5,5);
-		ql->setStyleSheet("background-color: rgba(255, 255, 255, 0);");
+		ql->setStyleSheet("color:rgba(0, 0, 0, 255); background-color: rgba(0, 0, 0, 0);");
 		ql->setWordWrap(true);
-		/*painter->drawText(QRect(0,0,0.8*width(),3*height()),
-			Qt::AlignLeft|Qt::TextDontClip|Qt::TextSingleLine|Qt::TextWordWrap,
-			textDocument[pagenum_prv-1]);*/
+// 		painter->drawText(QRect(0,0,0.8*width(),3*height()),
+// 			Qt::AlignLeft|Qt::TextDontClip|Qt::TextSingleLine|Qt::TextWordWrap,
+// 			textDocument[pagenum_prv-1]);
+		ql->setFrameStyle(QFrame::Panel | QFrame::Sunken);
 		ql->render(painter);
 		return;
 	}
@@ -862,6 +884,7 @@ void QPdfImage::paint(QPainter *painter, const QStyleOptionGraphicsItem*, QWidge
 }
 
 void QPdfImage::mousePressEvent(QGraphicsSceneMouseEvent *event){
+	emit allPressForward();
 	if(drawMode_prv){
 		PdfInkAnnotation* inkAnno = (PdfInkAnnotation*)  annos.last();
 		inkAnno->path.moveTo(event->pos().x()*100/zoom_prv,originalHeight_prv - event->pos().y()*100/zoom_y_prv);
@@ -888,9 +911,10 @@ void QPdfImage::mousePressEvent(QGraphicsSceneMouseEvent *event){
 		annos.last()->date = QDateTime::currentDateTime();
 		annos.last()->col = drawColor_prv;
 		annos.last()->setRect(QRectF(event->pos().x()*100/zoom_prv,
-			originalHeight_prv - event->pos().y()*100/zoom_y_prv,
-			20,
-			20));
+			originalHeight_prv - event->pos().y()*100/zoom_y_prv - 24,
+			24,
+			24));
+		update();
 		return;
 	}
 	QPoint clickP = event->pos().toPoint();
@@ -1321,4 +1345,4 @@ QString QPdfImage::title(){
 
 QVariantList QPdfImage::outline(){
 	return outline_prv;
-}
\ No newline at end of file
+}
