@@ -189,7 +189,8 @@ signals:
 	void textModeChanged(bool tm);
 	void textModeFontSizeChanged();
 	void grainyModeChanged(bool gm);
-	void clickForward();
+	void clickForward();//forward clicks, that don't have a meaning for qpdfimage
+	void allPressForward();//forward all mouse down events, even those, that may have a meaning for QPdfImage
 	void hitRectChanged();
 	void linkSelected(QVariant destination);
 	void linkHintsChanged(bool lh);
